# SPDX-FileCopyrightText: 2020 Jeff Epler
# SPDX-License-Identifier: MIT

"""
Helper for fork awesome icon names.

More info here: https://emergent.unpythonic.net/01606790241
"""
activitypub = "\uf2f2"
address_book_o = "\uf2ba"
address_book = "\uf2b9"
address_card_o = "\uf2bc"
address_card = "\uf2bb"
adjust = "\uf042"
adn = "\uf170"
align_center = "\uf037"
align_justify = "\uf039"
align_left = "\uf036"
align_right = "\uf038"
amazon = "\uf270"
ambulance = "\uf0f9"
american_sign_language_interpreting = "\uf2a3"
anchor = "\uf13d"
android = "\uf17b"
angellist = "\uf209"
angle_double_down = "\uf103"
angle_double_left = "\uf100"
angle_double_right = "\uf101"
angle_double_up = "\uf102"
angle_down = "\uf107"
angle_left = "\uf104"
angle_right = "\uf105"
angle_up = "\uf106"
apple = "\uf179"
archive_org = "\uf2fc"
archive = "\uf187"
archlinux = "\uf323"
area_chart = "\uf1fe"
arrow_circle_down = "\uf0ab"
arrow_circle_left = "\uf0a8"
arrow_circle_o_down = "\uf01a"
arrow_circle_o_left = "\uf190"
arrow_circle_o_right = "\uf18e"
arrow_circle_o_up = "\uf01b"
arrow_circle_right = "\uf0a9"
arrow_circle_up = "\uf0aa"
arrow_down = "\uf063"
arrow_left = "\uf060"
arrow_right = "\uf061"
arrows_alt = "\uf0b2"
arrows_h = "\uf07e"
arrows = "\uf047"
arrows_v = "\uf07d"
arrow_up = "\uf062"
artstation = "\uf2ed"
askfm = "\uf33a"
assistive_listening_systems = "\uf2a2"
asterisk = "\uf069"
att = "\uf31e"
at = "\uf1fa"
audio_description = "\uf29e"
backward = "\uf04a"
balance_scale = "\uf24e"
bandcamp = "\uf2d5"
ban = "\uf05e"
bar_chart = "\uf080"
barcode = "\uf02a"
bars = "\uf0c9"
bath = "\uf2cd"
battery_empty = "\uf244"
battery_full = "\uf240"
battery_half = "\uf242"
battery_quarter = "\uf243"
battery_three_quarters = "\uf241"
bed = "\uf236"
beer = "\uf0fc"
behance_square = "\uf1b5"
behance = "\uf1b4"
bell_o = "\uf0f3"
bell_ringing_o = "\uf330"
bell_ringing = "\uf32d"
bell_slash_o = "\uf1f7"
bell_slash = "\uf1f6"
bell = "\uf0a2"
bicycle = "\uf206"
binoculars = "\uf1e5"
biometric = "\uf32b"
birthday_cake = "\uf1fd"
bitbucket_square = "\uf172"
bitbucket = "\uf171"
black_tie = "\uf27e"
blind = "\uf29d"
blockstack = "\uf33b"
bluetooth_b = "\uf294"
bluetooth = "\uf293"
boardgamegeek = "\uf33c"
bold = "\uf032"
bolt = "\uf0e7"
bomb = "\uf1e2"
bookmark_o = "\uf097"
bookmark = "\uf02e"
book = "\uf02d"
bootstrap = "\uf315"
braille = "\uf2a1"
briefcase = "\uf0b1"
btc = "\uf15a"
bug = "\uf188"
building_o = "\uf0f7"
building = "\uf1ad"
bullhorn = "\uf0a1"
bullseye = "\uf140"
bunny = "\uf35f"
bus = "\uf207"
buymeacoffee = "\uf33d"
buysellads = "\uf20d"
calculator = "\uf1ec"
calendar_check_o = "\uf274"
calendar_minus_o = "\uf272"
calendar_o = "\uf133"
calendar_plus_o = "\uf271"
calendar_times_o = "\uf273"
calendar = "\uf073"
camera_retro = "\uf083"
camera = "\uf030"
caret_down = "\uf0d7"
caret_left = "\uf0d9"
caret_right = "\uf0da"
caret_square_o_down = "\uf150"
caret_square_o_left = "\uf191"
caret_square_o_right = "\uf152"
caret_square_o_up = "\uf151"
caret_up = "\uf0d8"
cart_arrow_down = "\uf218"
cart_plus = "\uf217"
car = "\uf1b9"
cc_amex = "\uf1f3"
cc_by = "\uf33e"
cc_cc = "\uf33f"
cc_diners_club = "\uf24c"
cc_discover = "\uf1f2"
cc_jcb = "\uf24b"
cc_mastercard = "\uf1f1"
cc_nc_eu = "\uf341"
cc_nc_jp = "\uf342"
cc_nc = "\uf340"
cc_nd = "\uf343"
cc_paypal = "\uf1f4"
cc_pd = "\uf344"
cc_remix = "\uf345"
cc_sa = "\uf346"
cc_share = "\uf347"
cc_stripe = "\uf1f5"
cc = "\uf20a"
cc_visa = "\uf1f0"
cc_zero = "\uf348"
certificate = "\uf0a3"
chain_broken = "\uf127"
check_circle_o = "\uf05d"
check_circle = "\uf058"
check_square_o = "\uf046"
check_square = "\uf14a"
check = "\uf00c"
chevron_circle_down = "\uf13a"
chevron_circle_left = "\uf137"
chevron_circle_right = "\uf138"
chevron_circle_up = "\uf139"
chevron_down = "\uf078"
chevron_left = "\uf053"
chevron_right = "\uf054"
chevron_up = "\uf077"
child = "\uf1ae"
chrome = "\uf268"
circle_o_notch = "\uf1ce"
circle_o = "\uf10c"
circle_thin = "\uf1db"
circle = "\uf111"
classicpress_circle = "\uf332"
classicpress = "\uf331"
clipboard = "\uf0ea"
clock_o = "\uf017"
clone = "\uf24d"
cloud_download = "\uf0ed"
cloud = "\uf0c2"
cloud_upload = "\uf0ee"
code_fork = "\uf126"
codepen = "\uf1cb"
code = "\uf121"
codiepie = "\uf284"
coffee = "\uf0f4"
cogs = "\uf085"
cog = "\uf013"
columns = "\uf0db"
commenting_o = "\uf27b"
commenting = "\uf27a"
comment_o = "\uf0e5"
comments_o = "\uf0e6"
comments = "\uf086"
comment = "\uf075"
compass = "\uf14e"
compress = "\uf066"
connectdevelop = "\uf20e"
contao = "\uf26d"
conway_glider = "\uf349"
copyright = "\uf1f9"
creative_commons = "\uf25e"
credit_card_alt = "\uf283"
credit_card = "\uf09d"
crop = "\uf125"
crosshairs = "\uf05b"
csharp = "\uf34a"
css3 = "\uf13c"
cubes = "\uf1b3"
cube = "\uf1b2"
c = "\uf31c"
cutlery = "\uf0f5"
dashcube = "\uf210"
database = "\uf1c0"
deaf = "\uf2a4"
debian = "\uf2ff"
delicious = "\uf1a5"
desktop = "\uf108"
deviantart = "\uf1bd"
dev_to = "\uf316"
diamond = "\uf219"
diaspora = "\uf2e5"
digg = "\uf1a6"
digitalocean = "\uf31d"
discord_alt = "\uf2ef"
discord = "\uf2ee"
dogmazic = "\uf303"
dot_circle_o = "\uf192"
download = "\uf019"
dribbble = "\uf17d"
dropbox = "\uf16b"
drupal = "\uf1a9"
edge = "\uf282"
eercast = "\uf2da"
eject = "\uf052"
ellipsis_h = "\uf141"
ellipsis_v = "\uf142"
email_bulk_o = "\uf34c"
email_bulk = "\uf34b"
emby = "\uf319"
empire = "\uf1d1"
envelope_open_o = "\uf2b7"
envelope_open = "\uf2b6"
envelope_o = "\uf003"
envelope_square = "\uf199"
envelope = "\uf0e0"
envira = "\uf299"
eraser = "\uf12d"
ethereum = "\uf2f3"
etsy = "\uf2d7"
eur = "\uf153"
exchange = "\uf0ec"
exclamation_circle = "\uf06a"
exclamation_triangle = "\uf071"
exclamation = "\uf12a"
expand = "\uf065"
expeditedssl = "\uf23e"
external_link_square = "\uf14c"
external_link = "\uf08e"
eyedropper = "\uf1fb"
eye_slash = "\uf070"
eye = "\uf06e"
facebook_messenger = "\uf2fe"
facebook_official = "\uf230"
facebook_square = "\uf082"
facebook = "\uf09a"
fast_backward = "\uf049"
fast_forward = "\uf050"
fax = "\uf1ac"
f_droid = "\uf32a"
female = "\uf182"
ffmpeg = "\uf30f"
fighter_jet = "\uf0fb"
file_archive_o = "\uf1c6"
file_audio_o = "\uf1c7"
file_code_o = "\uf1c9"
file_epub = "\uf321"
file_excel_o = "\uf1c3"
file_image_o = "\uf1c5"
file_o = "\uf016"
file_pdf_o = "\uf1c1"
file_powerpoint_o = "\uf1c4"
files_o = "\uf0c5"
file_text_o = "\uf0f6"
file_text = "\uf15c"
file_ = "\uf15b"
file_video_o = "\uf1c8"
file_word_o = "\uf1c2"
film = "\uf008"
filter_ = "\uf0b0"
fire_extinguisher = "\uf134"
firefox = "\uf269"
fire = "\uf06d"
first_order = "\uf2b0"
fivehundredpx = "\uf26e"
flag_checkered = "\uf11e"
flag_o = "\uf11d"
flag = "\uf024"
flask = "\uf0c3"
flickr = "\uf16e"
floppy_o = "\uf0c7"
folder_open_o = "\uf115"
folder_open = "\uf07c"
folder_o = "\uf114"
folder = "\uf07b"
font_awesome = "\uf2b4"
fonticons = "\uf280"
font = "\uf031"
fork_awesome = "\uf2e3"
fort_awesome = "\uf286"
forumbee = "\uf211"
forward = "\uf04e"
foursquare = "\uf180"
free_code_camp = "\uf2c5"
freedombox = "\uf2fd"
friendica = "\uf2e6"
frown_o = "\uf119"
funkwhale = "\uf339"
futbol_o = "\uf1e3"
gamepad = "\uf11b"
gavel = "\uf0e3"
gbp = "\uf154"
genderless = "\uf22d"
get_pocket = "\uf265"
gg_circle = "\uf261"
gg = "\uf260"
gift = "\uf06b"
gimp = "\uf31b"
gitea = "\uf31f"
github_alt = "\uf113"
github_square = "\uf092"
github = "\uf09b"
gitlab = "\uf296"
git_square = "\uf1d2"
git = "\uf1d3"
glass = "\uf000"
glide_g = "\uf2a6"
glide = "\uf2a5"
globe_e = "\uf304"
globe = "\uf0ac"
globe_w = "\uf305"
gnupg = "\uf30d"
gnu_social = "\uf2e7"
gnu = "\uf34d"
google_play = "\uf34e"
google_plus_official = "\uf2b3"
google_plus_square = "\uf0d4"
google_plus = "\uf0d5"
google = "\uf1a0"
google_wallet = "\uf1ee"
graduation_cap = "\uf19d"
gratipay = "\uf184"
grav = "\uf2d6"
hackaday = "\uf30a"
hacker_news = "\uf1d4"
hackster = "\uf326"
hal = "\uf333"
hand_lizard_o = "\uf258"
hand_o_down = "\uf0a7"
hand_o_left = "\uf0a5"
hand_o_right = "\uf0a4"
hand_o_up = "\uf0a6"
hand_paper_o = "\uf256"
hand_peace_o = "\uf25b"
hand_pointer_o = "\uf25a"
hand_rock_o = "\uf255"
hand_scissors_o = "\uf257"
handshake_o = "\uf2b5"
hand_spock_o = "\uf259"
hashnode = "\uf317"
hashtag = "\uf292"
hdd_o = "\uf0a0"
header = "\uf1dc"
headphones = "\uf025"
heartbeat = "\uf21e"
heart_o = "\uf08a"
heart = "\uf004"
heroku = "\uf34f"
history = "\uf1da"
home_assistant = "\uf350"
home = "\uf015"
hospital_o = "\uf0f8"
hourglass_end = "\uf253"
hourglass_half = "\uf252"
hourglass_o = "\uf250"
hourglass_start = "\uf251"
hourglass = "\uf254"
houzz = "\uf27c"
h_square = "\uf0fd"
html5 = "\uf13b"
hubzilla = "\uf2eb"
i_cursor = "\uf246"
id_badge = "\uf2c1"
id_card_o = "\uf2c3"
id_card = "\uf2c2"
ils = "\uf20b"
imdb = "\uf2d8"
inbox = "\uf01c"
indent = "\uf03c"
industry = "\uf275"
info_circle = "\uf05a"
info = "\uf129"
inkscape = "\uf312"
inr = "\uf156"
instagram = "\uf16d"
internet_explorer = "\uf26b"
ioxhost = "\uf208"
italic = "\uf033"
java = "\uf351"
jirafeau = "\uf318"
joomla = "\uf1aa"
joplin = "\uf310"
jpy = "\uf157"
jsfiddle = "\uf1cc"
julia = "\uf334"
jupyter = "\uf335"
keybase = "\uf2f4"
keyboard_o = "\uf11c"
key_modern = "\uf2f7"
key = "\uf084"
krw = "\uf159"
language = "\uf1ab"
laptop = "\uf109"
laravel = "\uf30b"
lastfm_square = "\uf203"
lastfm = "\uf202"
leaf = "\uf06c"
leanpub = "\uf212"
lemon_o = "\uf094"
level_down = "\uf149"
level_up = "\uf148"
liberapay_square = "\uf2e8"
liberapay = "\uf2e9"
life_ring = "\uf1cd"
lightbulb_o = "\uf0eb"
line_chart = "\uf201"
linkedin_square = "\uf08c"
linkedin = "\uf0e1"
link = "\uf0c1"
linode = "\uf2b8"
linux = "\uf17c"
list_alt = "\uf022"
list_ol = "\uf0cb"
list_ = "\uf03a"
list_ul = "\uf0ca"
location_arrow = "\uf124"
lock = "\uf023"
long_arrow_down = "\uf175"
long_arrow_left = "\uf177"
long_arrow_right = "\uf178"
long_arrow_up = "\uf176"
low_vision = "\uf2a8"
magic = "\uf0d0"
magnet = "\uf076"
male = "\uf183"
map_marker = "\uf041"
map_o = "\uf278"
map_pin = "\uf276"
map_signs = "\uf277"
map_ = "\uf279"
mariadb = "\uf352"
markdown = "\uf353"
mars_double = "\uf227"
mars_stroke_h = "\uf22b"
mars_stroke = "\uf229"
mars_stroke_v = "\uf22a"
mars = "\uf222"
mastodon_alt = "\uf2e2"
mastodon_square = "\uf300"
mastodon = "\uf2e1"
matrix_org = "\uf313"
maxcdn = "\uf136"
meanpath = "\uf20c"
medium_square = "\uf2f8"
medium = "\uf23a"
medkit = "\uf0fa"
meetup = "\uf2e0"
meh_o = "\uf11a"
mercury = "\uf223"
microchip = "\uf2db"
microphone_slash = "\uf131"
microphone = "\uf130"
minus_circle = "\uf056"
minus_square_o = "\uf147"
minus_square = "\uf146"
minus = "\uf068"
mixcloud = "\uf289"
mobile = "\uf10b"
modx = "\uf285"
money = "\uf0d6"
moon_o = "\uf186"
moon = "\uf328"
motorcycle = "\uf21c"
mouse_pointer = "\uf245"
music = "\uf001"
mysql = "\uf354"
neuter = "\uf22c"
newspaper_o = "\uf1ea"
nextcloud_square = "\uf307"
nextcloud = "\uf306"
nodejs = "\uf308"
nordcast = "\uf355"
object_group = "\uf247"
object_ungroup = "\uf248"
odnoklassniki_square = "\uf264"
odnoklassniki = "\uf263"
opencart = "\uf23d"
open_collective = "\uf336"
openid = "\uf19b"
opera = "\uf26a"
optin_monster = "\uf23c"
orcid = "\uf337"
outdent = "\uf03b"
pagelines = "\uf18c"
paint_brush = "\uf1fc"
paperclip = "\uf0c6"
paper_plane_o = "\uf1d9"
paper_plane = "\uf1d8"
paragraph = "\uf1dd"
patreon = "\uf2f0"
pause_circle_o = "\uf28c"
pause_circle = "\uf28b"
pause = "\uf04c"
paw = "\uf1b0"
paypal = "\uf1ed"
peertube = "\uf2e4"
pencil_square_o = "\uf044"
pencil_square = "\uf14b"
pencil = "\uf040"
percent = "\uf295"
phone_square = "\uf098"
phone = "\uf095"
php = "\uf30e"
picture_o = "\uf03e"
pie_chart = "\uf200"
pinterest_p = "\uf231"
pinterest_square = "\uf0d3"
pinterest = "\uf0d2"
pixelfed = "\uf314"
plane = "\uf072"
play_circle_o = "\uf01d"
play_circle = "\uf144"
play = "\uf04b"
pleroma = "\uf324"
plug = "\uf1e6"
plume = "\uf356"
plus_circle = "\uf055"
plus_square_o = "\uf196"
plus_square = "\uf0fe"
plus = "\uf067"
podcast = "\uf2ce"
postgresql = "\uf357"
power_off = "\uf011"
print_ = "\uf02f"
product_hunt = "\uf288"
puzzle_piece = "\uf12e"
python = "\uf322"
qq = "\uf1d6"
qrcode = "\uf029"
question_circle_o = "\uf29c"
question_circle = "\uf059"
question = "\uf128"
quora = "\uf2c4"
quote_left = "\uf10d"
quote_right = "\uf10e"
random = "\uf074"
ravelry = "\uf2d9"
react = "\uf302"
rebel = "\uf1d0"
recycle = "\uf1b8"
reddit_alien = "\uf281"
reddit_square = "\uf1a2"
reddit = "\uf1a1"
refresh = "\uf021"
registered = "\uf25d"
renren = "\uf18b"
repeat = "\uf01e"
reply_all = "\uf122"
reply = "\uf112"
researchgate = "\uf338"
retweet = "\uf079"
road = "\uf018"
rocket = "\uf135"
rss_square = "\uf143"
rss = "\uf09e"
rub = "\uf158"
safari = "\uf267"
sass_alt = "\uf359"
sass = "\uf358"
scissors = "\uf0c4"
scribd = "\uf28a"
scuttlebutt = "\uf2ea"
search_minus = "\uf010"
search_plus = "\uf00e"
search = "\uf002"
sellsy = "\uf213"
server = "\uf233"
shaarli_o = "\uf2f6"
shaarli = "\uf2f5"
share_alt_square = "\uf1e1"
share_alt = "\uf1e0"
share_square_o = "\uf045"
share_square = "\uf14d"
share = "\uf064"
shield = "\uf132"
ship = "\uf21a"
shirtsinbulk = "\uf214"
shopping_bag = "\uf290"
shopping_basket = "\uf291"
shopping_cart = "\uf07a"
shower = "\uf2cc"
signalapp = "\uf30c"
signal = "\uf012"
sign_in = "\uf090"
sign_language = "\uf2a7"
sign_out = "\uf08b"
simplybuilt = "\uf215"
sitemap = "\uf0e8"
skate = "\uf35a"
sketchfab = "\uf35b"
skyatlas = "\uf216"
skype = "\uf17e"
slack = "\uf198"
sliders = "\uf1de"
slideshare = "\uf1e7"
smile_o = "\uf118"
snapchat_ghost = "\uf2ac"
snapchat_square = "\uf2ad"
snapchat = "\uf2ab"
snowdrift = "\uf2f1"
snowflake_o = "\uf2dc"
social_home = "\uf2ec"
sort_alpha_asc = "\uf15d"
sort_alpha_desc = "\uf15e"
sort_amount_asc = "\uf160"
sort_amount_desc = "\uf161"
sort_asc = "\uf0de"
sort_desc = "\uf0dd"
sort_numeric_asc = "\uf162"
sort_numeric_desc = "\uf163"
sort = "\uf0dc"
soundcloud = "\uf1be"
space_shuttle = "\uf197"
spell_check = "\uf327"
spinner = "\uf110"
spoon = "\uf1b1"
spotify = "\uf1bc"
square_o = "\uf096"
square = "\uf0c8"
stack_exchange = "\uf18d"
stack_overflow = "\uf16c"
star_half_o = "\uf123"
star_half = "\uf089"
star_o = "\uf006"
star = "\uf005"
steam_square = "\uf1b7"
steam = "\uf1b6"
step_backward = "\uf048"
step_forward = "\uf051"
stethoscope = "\uf0f1"
sticky_note_o = "\uf24a"
sticky_note = "\uf249"
stop_circle_o = "\uf28e"
stop_circle = "\uf28d"
stop = "\uf04d"
street_view = "\uf21d"
strikethrough = "\uf0cc"
stumbleupon_circle = "\uf1a3"
stumbleupon = "\uf1a4"
subscript = "\uf12c"
subway = "\uf239"
suitcase = "\uf0f2"
sun_o = "\uf185"
sun = "\uf329"
superpowers = "\uf2dd"
superscript = "\uf12b"
syncthing = "\uf311"
tablet = "\uf10a"
table = "\uf0ce"
tachometer = "\uf0e4"
tags = "\uf02c"
tag = "\uf02b"
tasks = "\uf0ae"
taxi = "\uf1ba"
telegram = "\uf2c6"
television = "\uf26c"
tencent_weibo = "\uf1d5"
terminal = "\uf120"
text_height = "\uf034"
textpattern = "\uf35d"
text_width = "\uf035"
tex = "\uf35c"
themeisle = "\uf2b2"
thermometer_empty = "\uf2cb"
thermometer_full = "\uf2c7"
thermometer_half = "\uf2c9"
thermometer_quarter = "\uf2ca"
thermometer_three_quarters = "\uf2c8"
th_large = "\uf009"
th_list = "\uf00b"
th = "\uf00a"
thumbs_down = "\uf165"
thumbs_o_down = "\uf088"
thumbs_o_up = "\uf087"
thumbs_up = "\uf164"
thumb_tack = "\uf08d"
ticket = "\uf145"
times_circle_o = "\uf05c"
times_circle = "\uf057"
times = "\uf00d"
tint = "\uf043"
tipeee = "\uf301"
toggle_off = "\uf204"
toggle_on = "\uf205"
tor_onion = "\uf32e"
trademark = "\uf25c"
train = "\uf238"
transgender_alt = "\uf225"
transgender = "\uf224"
trash_o = "\uf014"
trash = "\uf1f8"
tree = "\uf1bb"
trello = "\uf181"
tripadvisor = "\uf262"
trophy = "\uf091"
truck = "\uf0d1"
try_ = "\uf195"
tty = "\uf1e4"
tumblr_square = "\uf174"
tumblr = "\uf173"
twitch = "\uf1e8"
twitter_square = "\uf081"
twitter = "\uf099"
umbrella = "\uf0e9"
underline = "\uf0cd"
undo = "\uf0e2"
unity = "\uf35e"
universal_access = "\uf29a"
university = "\uf19c"
unlock_alt = "\uf13e"
unlock = "\uf09c"
unsplash = "\uf325"
upload = "\uf093"
usb = "\uf287"
usd = "\uf155"
user_circle_o = "\uf2be"
user_circle = "\uf2bd"
user_md = "\uf0f0"
user_o = "\uf2c0"
user_plus = "\uf234"
user_secret = "\uf21b"
users = "\uf0c0"
user_times = "\uf235"
user = "\uf007"
venus_double = "\uf226"
venus_mars = "\uf228"
venus = "\uf221"
viacoin = "\uf237"
viadeo_square = "\uf2aa"
viadeo = "\uf2a9"
video_camera = "\uf03d"
vimeo_square = "\uf194"
vimeo = "\uf27d"
vine = "\uf1ca"
vk = "\uf189"
volume_control_phone = "\uf2a0"
volume_down = "\uf027"
volume_mute = "\uf32f"
volume_off = "\uf026"
volume_up = "\uf028"
weibo = "\uf18a"
weixin = "\uf1d7"
whatsapp = "\uf232"
wheelchair_alt = "\uf29b"
wheelchair = "\uf193"
wifi = "\uf1eb"
wikidata = "\uf31a"
wikipedia_w = "\uf266"
window_close_o = "\uf2d4"
window_close = "\uf2d3"
window_maximize = "\uf2d0"
window_minimize = "\uf2d1"
window_restore = "\uf2d2"
windows = "\uf17a"
wire = "\uf32c"
wordpress = "\uf19a"
wpbeginner = "\uf297"
wpexplorer = "\uf2de"
wpforms = "\uf298"
wrench = "\uf0ad"
xing_square = "\uf169"
xing = "\uf168"
xmpp = "\uf2f9"
yahoo = "\uf19e"
y_combinator = "\uf23b"
yelp = "\uf1e9"
yoast = "\uf2b1"
youtube_play = "\uf16a"
youtube_square = "\uf166"
youtube = "\uf167"
zotero = "\uf309"
